aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--usr.sbin/rarpd/rarpd.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/usr.sbin/rarpd/rarpd.c b/usr.sbin/rarpd/rarpd.c
index 57359efefbc3..bbe1b93a4467 100644
--- a/usr.sbin/rarpd/rarpd.c
+++ b/usr.sbin/rarpd/rarpd.c
@@ -33,8 +33,8 @@ static const char rcsid[] =
/*
* rarpd - Reverse ARP Daemon
*
* Usage: rarpd -a [ -dfsv ] [ hostname ]
* rarpd [ -dfsv ] interface [ hostname ]
*
* 'hostname' is optional solely for backwards compatibility with Sun's rarpd.
* Currently, the argument is ignored.
@@ -399,7 +399,7 @@ init(char *target)
void
usage(void)
{
- (void)fprintf(stderr, "usage: rarpd [-adfsv] [interface]\n");
+ (void)fprintf(stderr, "usage: rarpd [-adfsv] [-t directory] [interface]\n");
exit(1);
}
@@ -33,8 +33,8 @@ static const char rcsid[] =
* rarpd - Reverse ARP Daemon
*
- * Usage: rarpd -a [ -dfsv ] [ hostname ]
- * rarpd [ -dfsv ] interface [ hostname ]
+ * Usage: rarpd -a [ -dfsv ] [-t directory] [ hostname ]
+ * rarpd [ -dfsv ] [-t directory] interface [ hostname ]
*
* 'hostname' is optional solely for backwards compatibility with Sun's rarpd.